function [r, m] = bfrit(x, n, l, wpar)
% BFRIT  Block finite ridgelet transform
%	[r, m] = bfrit(x, n, l, wpar)
%
% Input:
%	x:	image matrix of size aN by bN, (2N-1) is a prime
%	n:	block size      
%	l:	number of wavelet decomposition levels
%	wpar:	parameters for spline biorthogonal filters, e.g. [1,3]
%
% Output:
%	r:	block ridgelet coefficients in a matrix
%	m:	block mean values
%
% Note:
%	This uses folded FRAT with symmetric extention and biorthogonal
%	symmetric wavelet transform (WaveLab function)
%
% See also:	FRATFD, FWT_SBS

if ~isprime(2*n-1)
    error('Block size must be n where (2n-1) is prime');
end

[lx, wx] = size(x);

a = floor(lx / n);
b = floor(wx / n);

if ((a * n) ~= lx) | ((b * n) ~= wx)
    error('Input image sizes must be multiple of n');
end

% Transform bock-by-block
r = zeros(n * a, (n+1) * b);
m = zeros(a, b);

for i = 1:a
    for j = 1:b
	[r((1+(i-1)*n):(i*n), (1+(j-1)*(n+1)):(j*(n+1))), ...
	 m(i, j)] = ...
	    fritfd(x((1+(i-1)*n):(i*n), (1+(j-1)*n):(j*n)), ...
	    l, wpar);
    end
end
