function x = ibfrit(r, m, l, wpar)
% IBFRIT  Inverse block finite ridgelet transform
%	x = ibfrit(r, m, l, wpar)
%
% Input:
%	r:	block ridgelet coefficients in a matrix
%	m:	block mean values
%	l:	number of wavelet decomposition levels
%	wpar:	parameters for spline biorthogonal filters, e.g. [1,3]
%
% Output:
%	x:	reconstructed image.
%
% Note:
%	This uses folded FRAT with symmetric extention and biorthogonal
%	symmetric wavelet transform (WaveLab function)
%
% See also:	BFRIT, IFRITFD

[a, b] = size(m);
n = size(r, 1) / a;

x = zeros(a * n, b * n);

% Inverse transform bock-by-block
for i = 1:a
    for j = 1:b
	x((1+(i-1)*n):(i*n), (1+(j-1)*n):(j*n)) = ...
	    ifritfd(r((1+(i-1)*n):(i*n), (1+(j-1)*(n+1)):(j*(n+1))), ...
		     m(i, j), l, wpar);
    end
end
