function x = ifritfd(r, m, l, wpar)
% IFRITFD  Inverse folded finite ridgelet transform
%	x = ifritfd(r, m, l, wpar)
%
% Input:
%	r:	ridgelet coefficients in a matrix, one column 
%		for each direction (there is N+1 directions)
%	m:	mean value of the folded image
%	l:	number of wavelet decomposition levels
%	wpar:	parameters for spline biorthogonal filters, e.g. [1,3]
%
% Output:
%	x:	reconstructed image
%
% See also:	FRITFD

% Columnwise inverse wavelet transform of the folded FRIT

% Retrieve the filters from input parameters
[qmf, dqmf] = MakeBSFilter('CDF', wpar);

%%% UN-OPTIMIZED Part (modified from WaveLab's FWT_SBS)
n = size(r, 1);
J = ceil(log(n)/log(2));
L = J - l;		% coarset level
dp = dyadpartition(n);

% Output
ra = zeros(n, n+1);

% Transpose ra since WaveLab operates on row vector
r = r';

for i = 1:n+1
    % IWT_SBS of the i-th "column" of r
    wcoef = r(i, :);
    rec = wcoef(1:dp(L+1));

    for j = L:J-1,
	dyadj = (dp(j+1)+1):dp(j+2);
	rec = UpDyad_SBS(rec, wcoef(dyadj), qmf, dqmf);
    end
   
    ra(:, i) = rec';
end

% Inverse folded FRAT
x = ifratfd(ra, m);